@@ -12,12 +12,23 @@ from fastapi.middleware.cors import CORSMiddleware
 from core import app_core
 from login import app_user_login
 
+from starlette.responses import FileResponse
+
+from datasets import get_favicon_path
+
+favicon_path = get_favicon_path(file="favicon.ico")
+
 app = FastAPI(
     title="欢迎来到为 AKShare 打造的 HTTP API 文档",
     description="AKTools 是 AKShare 的 HTTP API 工具, 主要目的是使 AKShare 的数据接口部署到本地从而通过 HTTP 访问来获取所需要的数据",
     version=akshare.__version__,
 )
 
+
+@app.get('/favicon.ico')
+async def favicon():
+    return FileResponse(favicon_path)
+
 origins = ["*"]
 
 app.add_middleware(
